@@ -4,11 +4,14 @@ import typing
 import uuid
 
 import marshmallow
+from marshmallow import fields
 from requests_mock.request import _RequestObjectProxy
 
-from commercetools import CommercetoolsError, schemas, types
-from commercetools.schemas import BaseResourceSchema
-from commercetools.services import abstract
+from commercetools import CommercetoolsError, types
+from commercetools._schemas._common import BaseResourceSchema
+from commercetools._schemas._error import DuplicateFieldErrorSchema, ErrorResponseSchema
+from commercetools.helpers import OptionalList
+from commercetools.services import traits
 from commercetools.testing import utils
 from commercetools.testing.predicates import PredicateFilter
 from commercetools.testing.utils import create_commercetools_response
@@ -35,7 +38,7 @@ class BaseModel:
 
     def add(self, draft, id=None):
         """Add a new object to the storage.
-        
+
         This will take a draft and generate an unique ID.
         """
         obj = self._create_from_draft(draft, id)
@@ -54,13 +57,12 @@ class BaseModel:
 
                 msg = f"A duplicate value '{value}' exists for field '{field}'."
                 error = types.DuplicateFieldError(
-                    code="DuplicateField",
                     message=msg,
                     field=field,
                     duplicate_value=value,
                     conflicting_resource=None,
                 )
-                serialized_errors = [schemas.DuplicateFieldErrorSchema().dump(error)]
+                serialized_errors = [DuplicateFieldErrorSchema().dump(error)]
                 raise CommercetoolsError(
                     msg,
                     errors=serialized_errors,
@@ -164,13 +166,22 @@ class BaseBackend:
             return create_commercetools_response(request, status_code=404)
 
 
+class GenericSchema(traits.QuerySchema, traits.SortableSchema, traits.PagingSchema):
+    where = OptionalList(fields.String())
+    sort = OptionalList(fields.String())
+    expand = OptionalList(fields.String())
+    limit = fields.Int()
+    offset = fields.Int()
+
+
 class ServiceBackend(BaseBackend):
     hostnames = ["api.sphere.io", "localhost"]
     model_class: typing.Any = None
-    _schema_draft: typing.Optional[marshmallow.Schema] = None
-    _schema_update: typing.Optional[marshmallow.Schema] = None
-    _schema_query_response: typing.Optional[marshmallow.Schema] = None
-    _schema_query_params: marshmallow.Schema = abstract.AbstractQuerySchema
+    _schema_draft: typing.Optional[typing.Type[marshmallow.Schema]] = None
+    _schema_update: typing.Optional[typing.Type[marshmallow.Schema]] = None
+    _schema_query_response: typing.Optional[typing.Type[marshmallow.Schema]] = None
+    _schema_query_params: marshmallow.Schema = GenericSchema
+    _query_default_limit = 20
 
     _verify_version: bool = True
 
@@ -205,8 +216,9 @@ class ServiceBackend(BaseBackend):
         params = utils.parse_request_params(self._schema_query_params, request)
         results = self.model.query(params.get("where"))
         total_count = len(results)
-        if params.get("limit"):
-            results = results[: params["limit"]]
+        limit = params.get("limit", self._query_default_limit)
+        if limit:
+            results = results[:limit]
 
         if params.get("expand"):
             expanded_results = []
@@ -218,6 +230,7 @@ class ServiceBackend(BaseBackend):
             "count": len(results),
             "total": total_count,
             "offset": 0,
+            "limit": limit,
             "results": self.model._resource_schema().load(results, many=True),
         }
         content = self._schema_query_response().dumps(data)
@@ -377,7 +390,7 @@ class ServiceBackend(BaseBackend):
         return obj, None
 
     def _create_data_error_response(self, message, obj):
-        return schemas.ErrorResponseSchema().dump(
+        return ErrorResponseSchema().dump(
             types.ErrorResponse(
                 status_code=400,
                 message=message,
@@ -390,7 +403,7 @@ class ServiceBackend(BaseBackend):
         )
 
     def _create_version_error_response(self, version):
-        return schemas.ErrorResponseSchema().dump(
+        return ErrorResponseSchema().dump(
             types.ErrorResponse(
                 status_code=409,
                 message="Version mismatch. Concurrent modification.",
