@@ -1,6 +1,7 @@
 import uuid
 
 import pytest
+import requests_mock
 from requests.exceptions import HTTPError
 
 from commercetools import types
@@ -10,8 +11,16 @@ def test_products_create(client):
     custom_type = client.types.create(
         types.TypeDraft(
             name=types.LocalizedString(en="myType"),
+            key="my-type",
             resource_type_ids=[types.ResourceTypeId.ASSET],
-            field_definitions=[types.FieldDefinition(name="foo")],
+            field_definitions=[
+                types.FieldDefinition(
+                    name="foo",
+                    type=types.CustomFieldStringType(),
+                    label=types.LocalizedString(en="foo"),
+                    required=False,
+                )
+            ],
         )
     )
     assert custom_type.id
@@ -19,13 +28,18 @@ def test_products_create(client):
     draft = types.ProductDraft(
         key="test-product",
         publish=True,
+        name=types.LocalizedString(en=f"my-product"),
+        slug=types.LocalizedString(en=f"my-product"),
+        product_type=types.ProductTypeResourceIdentifier(key="dummy"),
         master_variant=types.ProductVariantDraft(
             assets=[
                 types.AssetDraft(
+                    sources=[],
+                    name=types.LocalizedString(en="something"),
                     custom=types.CustomFieldsDraft(
                         type=types.TypeResourceIdentifier(id=custom_type.id),
                         fields=types.FieldContainer(foo="bar"),
-                    )
+                    ),
                 )
             ],
             prices=[
@@ -45,7 +59,15 @@ def test_products_create(client):
 
 
 def test_products_get_by_id(client):
-    product = client.products.create(types.ProductDraft(key="test-product"))
+    product = client.products.create(
+        types.ProductDraft(
+            key="test-product",
+            product_type=types.ProductTypeResourceIdentifier(key="dummy"),
+            name=types.LocalizedString(en="my-product"),
+            slug=types.LocalizedString(en="my-product"),
+            publish=True,
+        )
+    )
 
     assert product.id
     assert product.key == "test-product"
@@ -59,7 +81,15 @@ def test_products_get_by_id(client):
 
 
 def test_products_get_by_key(client):
-    product = client.products.create(types.ProductDraft(key="test-product"))
+    product = client.products.create(
+        types.ProductDraft(
+            key="test-product",
+            product_type=types.ProductTypeResourceIdentifier(key="dummy"),
+            name=types.LocalizedString(en="my-product"),
+            slug=types.LocalizedString(en="my-product"),
+            publish=True,
+        )
+    )
 
     assert product.id
     assert product.key == "test-product"
@@ -73,8 +103,24 @@ def test_products_get_by_key(client):
 
 
 def test_product_query(client):
-    client.products.create(types.ProductDraft(key="test-product1"))
-    client.products.create(types.ProductDraft(key="test-product2"))
+    client.products.create(
+        types.ProductDraft(
+            key=f"product-1",
+            product_type=types.ProductTypeResourceIdentifier(key="dummy"),
+            name=types.LocalizedString(en=f"my-product-1"),
+            slug=types.LocalizedString(en=f"my-product-1"),
+            publish=True,
+        )
+    )
+    client.products.create(
+        types.ProductDraft(
+            key=f"product-2",
+            product_type=types.ProductTypeResourceIdentifier(key="dummy"),
+            name=types.LocalizedString(en=f"my-product-2"),
+            slug=types.LocalizedString(en=f"my-product-2"),
+            publish=True,
+        )
+    )
 
     # single sort query
     result = client.products.query(sort="id asc", limit=2)
@@ -91,6 +137,9 @@ def test_product_query_where(client):
     client.products.create(
         types.ProductDraft(
             key="test-product1",
+            name=types.LocalizedString(en=f"my-product-1"),
+            slug=types.LocalizedString(en=f"my-product-1"),
+            product_type=types.ProductTypeResourceIdentifier(key="dummy"),
             master_variant=types.ProductVariantDraft(
                 prices=[
                     types.PriceDraft(
@@ -106,6 +155,9 @@ def test_product_query_where(client):
     client.products.create(
         types.ProductDraft(
             key="test-product-2",
+            name=types.LocalizedString(en=f"my-product-1"),
+            slug=types.LocalizedString(en=f"my-product-1"),
+            product_type=types.ProductTypeResourceIdentifier(key="dummy"),
             master_variant=types.ProductVariantDraft(
                 prices=[
                     types.PriceDraft(
@@ -118,7 +170,14 @@ def test_product_query_where(client):
             ),
         )
     )
-    client.products.create(types.ProductDraft(key="test-product2"))
+    client.products.create(
+        types.ProductDraft(
+            key="test-product2",
+            name=types.LocalizedString(en=f"my-product-1"),
+            slug=types.LocalizedString(en=f"my-product-1"),
+            product_type=types.ProductTypeResourceIdentifier(key="dummy"),
+        )
+    )
 
     result = client.products.query(
         where="masterData(staged(masterVariant(prices(country='NL'))))"
@@ -148,6 +207,9 @@ def test_product_update(client):
     product = client.products.create(
         types.ProductDraft(
             key="test-product",
+            name=types.LocalizedString(en=f"my-product-1"),
+            slug=types.LocalizedString(en=f"my-product-1"),
+            product_type=types.ProductTypeResourceIdentifier(key="dummy"),
             master_variant=types.ProductVariantDraft(sku="1", key="1"),
         )
     )
@@ -203,6 +265,9 @@ def test_product_update_add_change_price_staged(client):
     product = client.products.create(
         types.ProductDraft(
             key="test-product",
+            name=types.LocalizedString(en=f"my-product-1"),
+            slug=types.LocalizedString(en=f"my-product-1"),
+            product_type=types.ProductTypeResourceIdentifier(key="dummy"),
             master_variant=types.ProductVariantDraft(sku="1", key="1"),
         )
     )
@@ -250,6 +315,9 @@ def test_product_update_add_price_current(client):
     product = client.products.create(
         types.ProductDraft(
             key="test-product",
+            name=types.LocalizedString(en=f"my-product-1"),
+            slug=types.LocalizedString(en=f"my-product-1"),
+            product_type=types.ProductTypeResourceIdentifier(key="dummy"),
             master_variant=types.ProductVariantDraft(sku="1", key="1"),
             publish=True,
         )
@@ -271,3 +339,14 @@ def test_product_update_add_price_current(client):
 
     assert product.master_data.staged is None
     assert len(product.master_data.current.master_variant.prices) == 1
+
+
+def test_predicate_var(client):
+    with requests_mock.Mocker(real_http=True, case_sensitive=True) as m:
+
+        result = client.products.query(
+            where="masterData(staged(masterVariant(prices(country='NL'))))",
+            predicate_var={"foo": "bar"},
+        )
+
+        assert "var.foo" in m.request_history[0].qs
